package com.chinaitop.depot.feign;

import com.chinaitop.depot.common.HystrixClientFallback;

import java.util.List;
import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * @author qingsong.han
 * @description: basicWarehouse FeignService
 * @create 2020-07-20 9:20
 */
@FeignClient(name = "depot-basic", fallback = HystrixClientFallback.class)
public interface BasicFeignClient {

    /**
     * json参数说明:wareId货位id,crk_status 出入库状态标记(1空仓,2入库中,3封仓,4出库中,9其它)
     *
     * @param wareJson
     */
    @RequestMapping(value = "/Warehouse/updateWarehouseCrkStatus", method = RequestMethod.POST)
    void updateWarehouseCrkStatus(@RequestParam(value = "wareJson") String wareJson);
    
    
    @RequestMapping(value = "/depot/basic/file/updateFile", method = RequestMethod.POST)
    void updateFile(@RequestParam(value = "fileIds") String fileIds,@RequestParam(value = "bid") Integer bid,
    		@RequestParam(value = "fileType") String fileType);

    @RequestMapping(value = "/depot/basic/file/getList", method = RequestMethod.GET)
	List<BusinessFile> getList(@RequestParam(value = "bid") Integer bid, @RequestParam(value = "fileType") String fileType,@RequestParam(value = "order") String order,@RequestParam(value = "orgId") Integer orgId);

    /**
     * 获取字典树类型
     * @param parentId
     * @param notParentId
     * @param notEnumId
     * @return
     */
    @RequestMapping(value = "/Enum/findConditionEnum", method = RequestMethod.GET)
    Map<String, Object> findConditionEnum(@RequestParam(value = "parentId") Integer parentId, @RequestParam(value = "notParentId") Integer notParentId, @RequestParam(value = "notEnumId") Integer notEnumId);

    @RequestMapping(value = "/Enum/getIdByNameAndParentId", method = RequestMethod.GET)
    Map<String, Object> getIdByNameAndParentId(@RequestParam(value = "parentId") Integer parentId,@RequestParam(value = "enumName") String enumName, @RequestParam(value = "code") String code);

    @RequestMapping(value = "/Warehouse/getHouseIdBySptDataID", method = RequestMethod.GET)
    String getHouseIdBySptDataID(@RequestParam(value = "sptDataId") String sptDataId);

    @RequestMapping(value = "/Tank/getTankIdBySptDataID", method = RequestMethod.GET)
    String getTankIdBySptDataID(@RequestParam(value = "sptDataId") String sptDataId);

    @RequestMapping(value = "/Warehouse/getWareOrTankObj", method = RequestMethod.GET)
    Map<String, Object> getWareOrTankObj(@RequestParam(value = "sptDataId") String sptDataId);
}
