package com.chinaitop.depot.fumigation.service.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.fumigation.mapper.TFumigationAfterMapper;
import com.chinaitop.depot.fumigation.mapper.TFumigationProcessMapper;
import com.chinaitop.depot.fumigation.model.TFumigationAfter;
import com.chinaitop.depot.fumigation.model.TFumigationAfterExample;
import com.chinaitop.depot.fumigation.model.TFumigationForrecord;
import com.chinaitop.depot.fumigation.model.TFumigationForrecordExample;
import com.chinaitop.depot.fumigation.model.TFumigationProcess;
import com.chinaitop.depot.fumigation.model.TFumigationProcessExample;
import com.chinaitop.depot.fumigation.service.FumigationAfterService;
import com.chinaitop.depot.fumigation.service.FumigationForRecordService;
import com.chinaitop.depot.system.service.SysCodeService;
import com.chinaitop.depot.utils.OkHttpUtil;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;

import lombok.extern.slf4j.Slf4j;

/**
 * @author lvzhikai
 * @description: 熏蒸作业
 * @create 2019-1-15 11:00
 */
@Slf4j
@Service
public class FumigationAfterServiceImpl implements FumigationAfterService {

    @Resource
    private TFumigationAfterMapper tFumigationAfterMapper;
    @Resource
    private FumigationForRecordService fumigationForRecordService;
    @Resource
    private TFumigationProcessMapper fumigationProcessMapper;
    @Resource
	private SysCodeService sysCodeService;

    @Override
    public List<Map<String,Object>> getFumigationAfterList(Map<String, Object> map) {
        return tFumigationAfterMapper.getFumigationAfterList(map);
    }

    @Override
    public void add(TFumigationAfter tFumigationAfter) {
        tFumigationAfterMapper.insert(tFumigationAfter);
    }

    @Override
    public void update(TFumigationAfter tFumigationAfter) {
        tFumigationAfterMapper.updateByPrimaryKey(tFumigationAfter);
    }

    @Override
    public TFumigationAfter findById(String afterId) {
        return tFumigationAfterMapper.selectByPrimaryKey(afterId);
    }

    @Override
    public void updateByExample(TFumigationAfter tFumigationAfter, TFumigationAfterExample example) {
        tFumigationAfterMapper.updateByExampleSelective(tFumigationAfter, example);
    }

    @Override
    public List<TFumigationAfter> findByFumigationId(String fumigationId) {
        TFumigationAfterExample example = new TFumigationAfterExample();
        TFumigationAfterExample.Criteria criteria = example.createCriteria();
        criteria.andFumigationIdEqualTo(fumigationId);
        return tFumigationAfterMapper.selectByExample(example);
    }

    /**
     * 获取作业列表
     * @param map
     * @return
     */
    @Override
    public List<Map<String,Object>> selectHomeWorkQueryList(Map<String, Object> map) {
        return tFumigationAfterMapper.selectHomeWorkQueryList(map);
    }

	@Override
	public Map<String, Object> saveOrUpdate(String fumigationAfter, String fumigationProcess) throws Exception {
		Map<String, Object> modelMap = new HashMap<String, Object>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        TFumigationAfter tFumigationAfter = mapper.readValue(fumigationAfter, TFumigationAfter.class);
        tFumigationAfter.setDeleteState("1");//默认设置删除标志
        if (tFumigationAfter.getId() == null) {
            tFumigationAfter.setCreateTime(new Date());//创建时间
            tFumigationAfter.setUpdateTime(tFumigationAfter.getCreateTime());//最后修改时间
            tFumigationAfter.setId(ParameterUtil.getCode());

            add(tFumigationAfter);


        } else {
            tFumigationAfter.setUpdateTime(new Date());//修改时间
            update(tFumigationAfter);
        }
        
        //回写熏蒸散气信息到作业表中
        TFumigationProcess pro = mapper.readValue(fumigationProcess, TFumigationProcess.class);
        TFumigationProcessExample processExample = new TFumigationProcessExample();
        TFumigationProcessExample.Criteria proCriteria = processExample.createCriteria();
        proCriteria.andRecordIdEqualTo(tFumigationAfter.getRecordId());
        List<TFumigationProcess> proList = fumigationProcessMapper.selectByExample(processExample);
        if (null != proList && proList.size() > 0) {
        	TFumigationProcess newpro = proList.get(0);
            newpro.setBulkStartTime(pro.getBulkStartTime());
            newpro.setBulkEndTime(pro.getBulkEndTime());
            newpro.setPerforatedDays(pro.getPerforatedDays());
            newpro.setClosedTime(pro.getClosedTime());
            newpro.setCtValue(pro.getCtValue());
            newpro.setPerforatedBefore(pro.getPerforatedBefore());
            newpro.setPerforatedEnd(pro.getPerforatedEnd());
            newpro.setBulkGasType(pro.getBulkGasType());
            newpro.setDrugResidueRate(pro.getDrugResidueRate());
            newpro.setPerforatedApprover(pro.getPerforatedApprover());
            newpro.setRemark(pro.getRemark());
            fumigationProcessMapper.updateByPrimaryKey(newpro);
        }
        
        //修改熏蒸状态
        if ("1".equals(tFumigationAfter.getDataStatus())) {
        	TFumigationForrecordExample example = new TFumigationForrecordExample();
        	TFumigationForrecordExample.Criteria criteria = example.createCriteria();
        	criteria.andIdEqualTo(tFumigationAfter.getRecordId());
        	
        	TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
        	tFumigationForrecord.setState(10);
        	fumigationForRecordService.updateByExample(tFumigationForrecord, example);

        	//把善后结果中[残渣收集作业结束时间]返回给市平台
        	pushFAfterData(ParameterUtil.datetime2string(tFumigationAfter.getSjczsjzyjssj()), tFumigationAfter.getRecordId());
        }
        
        
        modelMap.put("status", "success");
		return modelMap;
	}
	
	private String pushFAfterData(String sjczsjzyjssj, String tFumigationForrecordId) throws Exception {
		String result = "";
		
		//获取当前数据引用的备案数据
		TFumigationForrecord tFumigationForrecord = fumigationForRecordService.getById(tFumigationForrecordId);

		//组装参数
		JSONObject object = new JSONObject();
		object.put("applyId", tFumigationForrecord.getXzzydh());
		object.put("cfbh", tFumigationForrecord.getCfdm());
		object.put("residueEnd", sjczsjzyjssj);
		
		//获取推送URL链接
		String path = sysCodeService.getSVal(10, "xzshData");
		StringBuffer sbf = new StringBuffer(50);
		sbf.append("param=").append(object.toString());
		
		log.info("熏蒸善后结束给市平台推送数据URL："+path);
		log.info("熏蒸善后结束给市平台推送数据参数："+sbf.toString());

		OkHttpUtil.postXWFU(path, sbf.toString());
		log.info("推送正常!");

		return result;
	}
}
