package com.chinaitop.depot.risk.controller;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestTemplate;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.common.Constants;
import com.chinaitop.depot.risk.response.LawRegulationsResponse;
import com.chinaitop.depot.risk.service.LawsRegulationsInfoBaseService;
import com.chinaitop.depot.system.service.SysCodeService;
import com.chinaitop.depot.utils.OkHttpUtil;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 *
 * 法律规章信息库
 *
 * @author aihua
 * @date 2022-04-20 16:17
 */
@RestController
@RequestMapping(value = "lawRegulationInfo")
@SuppressWarnings("all")
@Api(value = "lawsRegulationsInfoBaseController", description = "法律规章信息库-主页)")
public class LawsRegulationsInfoBaseController {

	@Value("${api.safety.host}")
	private String host;
	@Value("${api.safety.port}")
	private String port;

	@Resource
	private LawsRegulationsInfoBaseService lawsRegulationsInfoBaseService;

    /*@Autowired
    private RestTemplate restTemplate;*/

    @RequestMapping(value = "/getLawRegulationInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "法律规章信息库查询", notes = "查询法律规章信息库列表,支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "起始页", defaultValue = "1", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "页面大小", defaultValue = "10", paramType = "query")
    })
    public ResponseEntity<Object> getLawRegulationInfo(Integer pageNum, Integer pageSize) {
        //String url = "http://" + host + ":" + port + "/api/safety-app/prod_system/page_info/" + pageNum + "/" + pageSize;

        LawRegulationsResponse response = null;
		try {
			response = lawsRegulationsInfoBaseService.getSptFlgzxxkData(pageNum, pageSize);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return ResponseEntity.ok(response.getData());
    }

    @RequestMapping(value = "/download", method = RequestMethod.GET)
    @ApiOperation(value = "法律规章信息附件下载", notes = "下载法律规章信息附件")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fileId", value = "文件下载ID", paramType = "query")
    })
    public ResponseEntity<byte[]> downlaodFile(String fileId) {
        if (StringUtils.isBlank(fileId)) {
            return (ResponseEntity<byte[]>) ResponseEntity.notFound();
        }
        //String url =  "http://" + host + ":" + port + "/api/file/file/download?id=" + fileId;
        ResponseEntity<byte[]> re = null;
        try {
			re = lawsRegulationsInfoBaseService.downlaodFile(fileId);
		} catch (Exception e) {
			e.printStackTrace();
		}
        return re;
    }

    /*@Bean
    public RestTemplate restTemplate() {
        return new RestTemplate();
    }*/
}

